Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var (
Injectables = []Injectable{&Options{}}
)
Functions ¶
Types ¶
type FeatureGates ¶
type FeatureGates struct {
Drift bool
SpotToSpotConsolidation bool
// contains filtered or unexported fields
}
func ParseFeatureGates ¶
func ParseFeatureGates(gateStr string) (FeatureGates, error)
type Injectable ¶
type Injectable interface {
// AddFlags adds the injectable's flags to karpenter's flag set
AddFlags(*FlagSet)
// Parse parses the flag set and handles any required post-processing on
// the flags
Parse(*FlagSet, ...string) error
// ToContext injects the callee into the given context
ToContext(context.Context) context.Context
}
Injectable defines a set of flag based options to be parsed and injected into Karpenter's contexts
type Options ¶
type Options struct {
ServiceName string
DisableWebhook bool
WebhookPort int
MetricsPort int
WebhookMetricsPort int
HealthProbePort int
KubeClientQPS int
KubeClientBurst int
EnableProfiling bool
EnableLeaderElection bool
MemoryLimit int64
LogLevel string
BatchMaxDuration time.Duration
BatchIdleDuration time.Duration
FeatureGates FeatureGates
}
Options contains all CLI flags / env vars for karpenter-core. It adheres to the options.Injectable interface.
func FromContext ¶
Click to show internal directories.
Click to hide internal directories.